/*
 * ============================================================================
 *  Title:    Controller pads
 *  Author:   J. Zbiciak
 *  $Id: pads.h,v 1.9 1999/09/14 20:24:58 im14u2c Exp $
 * ============================================================================
 *  This module implements the controller pads.
 *  Pads are peripherals that extend periph_t.
 * ============================================================================
 */

#ifndef _PAD_H
#define _PAD_H

/*
 * ============================================================================
 *  PAD_T        -- Controller Pad structure
 * ============================================================================
 */
typedef struct pad_t
{
    periph_t    periph;     /*  Peripheral structure.                       */
    uint_32     io_base;    /*  I/O port that HCIF is on.                   */
    uint_32     rd_state;   /*  State-machine counter.                      */
    uint_32     rd_val;     /*  Value being read from HCIF.                 */
    uint_32     last_evt;   /*  Last event number processed.                */
    uint_8      side[2];    /*  Last read values from each controller.      */

    uint_32     l[16]; 
    uint_32     r[16];      /*  Event inputs to left and right controls.    */
} pad_t;

/*
 * ============================================================================
 *  PAD_READ     -- Reads the hand controller pad (read or emulated).
 * ============================================================================
 */
uint_32 pad_read        (periph_t *, periph_t *, uint_32, uint_32);

/*
 * ============================================================================
 *  PAD_TK_EVENT -- Updates that pad's states according to event inputs.
 * ============================================================================
 */
sint_32 pad_tk_event(periph_t *p, sint_32 len);

/*
 * ============================================================================
 *  PAD_INIT     -- Makes an input pad device
 * ============================================================================
 */
int pad_init
(
    pad_t           *pad,       /*  mem_t structure to initialize   */
    uint_32         addr,       /*  Base address of pad.            */
    uint_32         io_base     /*  Hand contr interface IO base.   */
);

#ifdef DIRECT_HCIF
extern int pads_hcif_ok;

/*
 * ============================================================================
 *  PAD_TK_HCIF  -- Reads from a dummy pad
 * ============================================================================
 */
sint_32 pad_tk_hcif(periph_t *p, sint_32 len);

#endif /* DIRECT_HCIF */

#endif

/* ======================================================================== */
/*  This program is free software; you can redistribute it and/or modify    */
/*  it under the terms of the GNU General Public License as published by    */
/*  the Free Software Foundation; either version 2 of the License, or       */
/*  (at your option) any later version.                                     */
/*                                                                          */
/*  This program is distributed in the hope that it will be useful,         */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       */
/*  General Public License for more details.                                */
/*                                                                          */
/*  You should have received a copy of the GNU General Public License       */
/*  along with this program; if not, write to the Free Software             */
/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.               */
/* ======================================================================== */
/*                 Copyright (c) 1998-1999, Joseph Zbiciak                  */
/* ======================================================================== */
